Documentation
¶
Overview ¶
Package alertmanagerexporter exports spanevents as alerts to Prometheus Alertmanager
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for Alertmanager exporter
Types ¶
type Config ¶
type Config struct {
TimeoutSettings exporterhelper.TimeoutConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
QueueSettings configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
BackoffConfig configretry.BackOffConfig `mapstructure:"retry_on_failure"`
confighttp.ClientConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
GeneratorURL string `mapstructure:"generator_url"`
DefaultSeverity string `mapstructure:"severity"`
SeverityAttribute string `mapstructure:"severity_attribute"`
APIVersion string `mapstructure:"api_version"`
EventLabels []string `mapstructure:"event_labels"`
}
Config defines configuration for alertmanager exporter.
Click to show internal directories.
Click to hide internal directories.