Documentation
¶
Overview ¶
Package carbonexporter implements an exporter that sends data to Carbon.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶ added in v0.9.0
NewFactory creates a factory for Carbon exporter.
Types ¶
type Config ¶
type Config struct {
// Specifies the connection endpoint config. The default value is "localhost:2003".
confignet.TCPAddrConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
// MaxIdleConns is used to set a limit to the maximum idle TCP connections the client can keep open. Default value is 100.
// If `sending_queue` is enabled, it is recommended to use same value as `sending_queue::num_consumers`.
MaxIdleConns int `mapstructure:"max_idle_conns"`
// Timeout is the maximum duration allowed to connecting and sending the
// data to the Carbon/Graphite backend. The default value is 5s.
TimeoutSettings exporterhelper.TimeoutConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
QueueConfig exporterhelper.QueueBatchConfig `mapstructure:"sending_queue"`
RetryConfig configretry.BackOffConfig `mapstructure:"retry_on_failure"`
// ResourceToTelemetrySettings defines configuration for converting resource attributes to metric labels.
ResourceToTelemetryConfig resourcetotelemetry.Settings `mapstructure:"resource_to_telemetry_conversion"`
}
Config defines configuration for Carbon exporter.
Click to show internal directories.
Click to hide internal directories.