Documentation
¶
Overview ¶
Package honeycombmarkerexporter exports Marker data to Honeycomb.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
Types ¶
type Config ¶
type Config struct {
// APIKey is the authentication token associated with the Honeycomb account.
APIKey configopaque.String `mapstructure:"api_key"`
// API URL to use (defaults to https://api.honeycomb.io)
APIURL string `mapstructure:"api_url"`
// Markers is the list of markers to create
Markers []Marker `mapstructure:"markers"`
confighttp.ClientConfig `mapstructure:",squash"`
QueueSettings configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
configretry.BackOffConfig `mapstructure:"retry_on_failure"`
}
Config defines configuration for the Honeycomb Marker exporter.
type Marker ¶
type Marker struct {
// Type defines the type of Marker.
Type string `mapstructure:"type"`
// MessageKey is the attribute that will be used as the message.
// If necessary the value will be converted to a string.
MessageKey string `mapstructure:"message_key"`
// URLKey is the attribute that will be used as the url.
// If necessary the value will be converted to a string.
URLKey string `mapstructure:"url_key"`
// Rules are the OTTL rules that determine when a piece of telemetry should be turned into a Marker
Rules Rules `mapstructure:"rules"`
// DatasetSlug is the endpoint that specifies the Honeycomb environment
DatasetSlug string `mapstructure:"dataset_slug"`
}
Click to show internal directories.
Click to hide internal directories.