Documentation
¶
Overview ¶
Package opencensusexporter exports data to an OpenCensus agent. Deprecated: this exporter is no longer maintained and has reached end-of-life. See https://github.com/open-telemetry/opentelemetry-collector-contrib/issues/36791
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for OTLP exporter.
Types ¶
type Config ¶
type Config struct {
configgrpc.ClientConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
QueueSettings exporterhelper.QueueBatchConfig `mapstructure:"sending_queue"`
configretry.BackOffConfig `mapstructure:"retry_on_failure"`
// The number of workers that send the gRPC requests.
NumWorkers int `mapstructure:"num_workers"`
}
Config defines configuration for OpenCensus exporter.
Click to show internal directories.
Click to hide internal directories.