Documentation
¶
Overview ¶
Package sapmexporter sends traces to a SAPM endpoint.
Deprecated: [v0.143.0] Use OTLP exporter instead
Package sapmexporter exports trace data using Splunk's SAPM protocol.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶ added in v0.7.0
NewFactory creates a factory for SAPM exporter.
Types ¶
type Config ¶
type Config struct {
// Endpoint is the destination to where traces will be sent to in SAPM format.
// It must be a full URL and include the scheme, port and path e.g, https://ingest.signalfx.com/v2/trace
Endpoint string `mapstructure:"endpoint"`
// AccessToken is the authentication token provided by SignalFx.
AccessToken configopaque.String `mapstructure:"access_token"`
// NumWorkers is the number of workers that should be used to export traces.
// Exporter can make as many requests in parallel as the number of workers. Defaults to 8.
NumWorkers uint `mapstructure:"num_workers"`
// MaxConnections is used to set a limit to the maximum idle HTTP connection the exporter can keep open.
MaxConnections uint `mapstructure:"max_connections"`
// Disable compression. If set to true then Compression field is ignored.
DisableCompression bool `mapstructure:"disable_compression"`
// Compression method to use (gzip or zstd). Ignored if DisableCompression=true.
// If unspecified defaults to gzip.
Compression string `mapstructure:"compression"`
// Log detailed response from trace ingest.
LogDetailedResponse bool `mapstructure:"log_detailed_response"`
splunk.AccessTokenPassthroughConfig `mapstructure:",squash"`
TimeoutSettings exporterhelper.TimeoutConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
QueueSettings configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
configretry.BackOffConfig `mapstructure:"retry_on_failure"`
}
Config defines configuration for SAPM exporter.
Click to show internal directories.
Click to hide internal directories.