Documentation
¶
Index ¶
Constants ¶
const ( // TextFormat represents log_format: text TextFormat LogFormatType = "text" // JSONFormat represents log_format: json JSONFormat LogFormatType = "json" // OTLPLogFormat represents log_format: otlp OTLPLogFormat LogFormatType = "otlp" // RemovedGraphiteFormat represents the no longer supported graphite metric format RemovedGraphiteFormat MetricFormatType = "graphite" // RemovedCarbon2Format represents the no longer supported carbon2 metric format RemovedCarbon2Format MetricFormatType = "carbon2" // PrometheusFormat represents metric_format: prometheus PrometheusFormat MetricFormatType = "prometheus" // OTLPMetricFormat represents metric_format: otlp OTLPMetricFormat MetricFormatType = "otlp" // OTLPTraceFormat represents trace_format: otlp OTLPTraceFormat TraceFormatType = "otlp" // NoCompression represents disabled compression NoCompression configcompression.Type = "" // MetricsPipeline represents metrics pipeline MetricsPipeline PipelineType = "metrics" // LogsPipeline represents metrics pipeline LogsPipeline PipelineType = "logs" // TracesPipeline represents traces pipeline TracesPipeline PipelineType = "traces" // DefaultCompress defines default Compress DefaultCompress bool = true // DefaultCompressEncoding defines default CompressEncoding DefaultCompressEncoding configcompression.Type = "gzip" // DefaultMaxRequestBodySize defines default MaxRequestBodySize in bytes DefaultMaxRequestBodySize int = 1 * 1024 * 1024 // DefaultLogFormat defines default LogFormat DefaultLogFormat LogFormatType = OTLPLogFormat // DefaultMetricFormat defines default MetricFormat DefaultMetricFormat MetricFormatType = OTLPMetricFormat // DefaultClient defines default Client DefaultClient string = "otelcol" // DefaultLogKey defines default LogKey value DefaultLogKey string = "log" // DefaultDropRoutingAttribute defines default DropRoutingAttribute DefaultDropRoutingAttribute string = "" // DefaultStickySessionEnabled defines default StickySessionEnabled value DefaultStickySessionEnabled bool = false // DefaultRetryOnFailureMultiplier defines default retry_on_failure multiplier value DefaultRetryOnFailureMultiplier float64 = 1.2 // DefaultRetryOnFailureMaxInterval defines default retry_on_failure max_interval value DefaultRetryOnFailureMaxInterval time.Duration = 5 * time.Minute // DefaultRetryOnFailureMaxElapsedTime defines default retry_on_failure max_elapsed_time value DefaultRetryOnFailureMaxElapsedTime time.Duration = 1 * time.Hour )
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory returns a new factory for the sumologic exporter.
Types ¶
type Config ¶
type Config struct {
confighttp.ClientConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
QueueSettings configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
configretry.BackOffConfig `mapstructure:"retry_on_failure"`
// Compression encoding format, either empty string, gzip or deflate (default gzip)
// Empty string means no compression
// NOTE: CompressEncoding is deprecated and will be removed in an upcoming release
CompressEncoding *configcompression.Type `mapstructure:"compress_encoding"`
// Max HTTP request body size in bytes before compression (if applied).
// By default 1MB is recommended.
MaxRequestBodySize int `mapstructure:"max_request_body_size"`
// Logs related configuration
// Format to post logs into Sumo. (default json)
// * text - Logs will appear in Sumo Logic in text format.
// * json - Logs will appear in Sumo Logic in json format.
// * otlp - Logs will be send in otlp format and will appear in Sumo Logic:
// * in json format if record level attributes exists
// * in text format in case of no level attributes
// See Sumo Logic documentation for more details:
// https://help.sumologic.com/docs/send-data/opentelemetry-collector/data-source-configurations/mapping-records-resources/
LogFormat LogFormatType `mapstructure:"log_format"`
// Metrics related configuration
// The format of metrics you will be sending, either otlp or prometheus (Default is otlp)
MetricFormat MetricFormatType `mapstructure:"metric_format"`
// Decompose OTLP Histograms into individual metrics, similar to how they're represented in Prometheus format
DecomposeOtlpHistograms bool `mapstructure:"decompose_otlp_histograms"`
// Decompose OTLP Summaries into individual metrics (quantiles as gauges, count/sum as counters)
DecomposeOtlpSummaries bool `mapstructure:"decompose_otlp_summaries"`
// Sumo specific options
// Name of the client
Client string `mapstructure:"client"`
// StickySessionEnabled defines if sticky session support is enable.
// By default this is false.
StickySessionEnabled bool `mapstructure:"sticky_session_enabled"`
}
Config defines configuration for Sumo Logic exporter.
type TraceFormatType ¶ added in v0.102.0
type TraceFormatType string
TraceFormatType represents trace_format
Source Files
¶
Click to show internal directories.
Click to hide internal directories.