Documentation
¶
Overview ¶
Package zipkinexporter exports trace data to Zipkin.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for Zipkin exporter.
Types ¶
type Config ¶
type Config struct {
QueueSettings configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
configretry.BackOffConfig `mapstructure:"retry_on_failure"`
// Configures the exporter client.
// The Endpoint to send the Zipkin trace data to (e.g.: http://some.url:9411/api/v2/spans).
confighttp.ClientConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
Format string `mapstructure:"format"`
DefaultServiceName string `mapstructure:"default_service_name"`
}
Config defines configuration settings for the Zipkin exporter.
Click to show internal directories.
Click to hide internal directories.