package
module
Version:
v0.151.0
Opens a new window with list of versions in this module.
Published: Apr 28, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
README
¶
Zipkin Encoding Extension
This extension supports marshaling and unmarshalling Zipkin data representing traces.
The extension supports the following configuration options:
protocol: either zipkin_proto, zipkin_json or zipkin_thrift
version: v1 or v2
The default configuration is as follows:
extensions:
zipkin_encoding:
protocol: zipkin_proto
version: v2
Documentation
¶
type Config struct {
Protocol string `mapstructure:"protocol"`
Version string `mapstructure:"version"`
}
Source Files
¶
Directories
¶
internal
|
|
metadata
Package metadata contains the autogenerated telemetry and build information for the extension/zipkin_encoding component.
|
Package metadata contains the autogenerated telemetry and build information for the extension/zipkin_encoding component. |
Click to show internal directories.
Click to hide internal directories.