Documentation
¶
Overview ¶
Package httpforwarderextension accepts HTTP requests, optionally adds headers to them and forwards them.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for HostObserver extension.
Types ¶
type Config ¶
type Config struct {
// Ingress holds config settings for HTTP server listening for requests.
Ingress confighttp.ServerConfig `mapstructure:"ingress"`
// Egress holds config settings to use for forwarded requests.
Egress confighttp.ClientConfig `mapstructure:"egress"`
}
Config defines configuration for http forwarder extension.
Click to show internal directories.
Click to hide internal directories.