Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Settings ¶
type Settings struct {
// Enabled indicates whether to convert resource attributes to telemetry attributes. Default is `false`.
Enabled bool `mapstructure:"enabled"`
// ExcludeServiceAttributes indicates whether to exclude `service.name`, `service.instance.id` and `service.namespace`
// resource attributes from being converted to metric attributes. Default is `false`.
// When set to `true`, these attributes will not be added to metric labels since they are
// already mapped to Prometheus `job` and `instance` labels respectively.
ExcludeServiceAttributes bool `mapstructure:"exclude_service_attributes"`
}
Settings defines configuration for converting resource attributes to telemetry attributes. When used, it must be embedded in the exporter configuration:
type Config struct {
// ...
resourcetotelemetry.Settings `mapstructure:"resource_to_telemetry_conversion"`
}
Click to show internal directories.
Click to hide internal directories.