Documentation
¶
Index ¶
Constants ¶
const ( // DefaultMaxLogSize is the max buffer sized used // if MaxLogSize is not set DefaultMaxLogSize = 1024 * 1024 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BaseConfig ¶ added in v0.53.0
type BaseConfig struct {
MaxLogSize helper.ByteSize `mapstructure:"max_log_size,omitempty"`
ListenAddress string `mapstructure:"listen_address,omitempty"`
TLS *configtls.ServerConfig `mapstructure:"tls,omitempty"`
AddAttributes bool `mapstructure:"add_attributes,omitempty"`
OneLogPerPacket bool `mapstructure:"one_log_per_packet,omitempty"`
Encoding string `mapstructure:"encoding,omitempty"`
SplitConfig split.Config `mapstructure:"multiline,omitempty"`
TrimConfig trim.Config `mapstructure:",squash"`
SplitFuncBuilder SplitFuncBuilder `mapstructure:"-"`
}
BaseConfig is the detailed configuration of a tcp input operator.
type Config ¶ added in v0.53.0
type Config struct {
helper.InputConfig `mapstructure:",squash"`
BaseConfig `mapstructure:",squash"`
}
Config is the configuration of a tcp input operator.
func NewConfig ¶ added in v0.53.0
func NewConfig() *Config
NewConfig creates a new TCP input config with default values
func NewConfigWithID ¶ added in v0.59.0
NewConfigWithID creates a new TCP input config with default values
type Input ¶ added in v0.53.0
type Input struct {
helper.InputOperator
MaxLogSize int
OneLogPerPacket bool
// contains filtered or unexported fields
}
Input is an operator that listens for log entries over tcp.
Click to show internal directories.
Click to hide internal directories.