Documentation
¶
Overview ¶
package intervalprocessor implements a processor which aggregates cumulative metrics over time, and periodically exports the latest values
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrInvalidIntervalValue = errors.New("invalid interval value")
Functions ¶
func NewFactory ¶
NewFactory returns a new factory for the Metrics Generation processor.
Types ¶
type Config ¶
type Config struct {
// Interval is the time interval at which the processor will aggregate metrics.
Interval time.Duration `mapstructure:"interval"`
// PassThrough is a configuration that determines whether gauge and summary metrics should be passed through
// as they are or aggregated.
PassThrough PassThrough `mapstructure:"pass_through"`
}
Config defines the configuration for the processor.
type PassThrough ¶ added in v0.109.0
type PassThrough struct {
// Gauge is a flag that determines whether gauge metrics should be passed through
// as they are or aggregated.
Gauge bool `mapstructure:"gauge"`
// Summary is a flag that determines whether summary metrics should be passed through
// as they are or aggregated.
Summary bool `mapstructure:"summary"`
}
Click to show internal directories.
Click to hide internal directories.