Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
Types ¶
type Config ¶
type Config struct {
confighttp.ClientConfig `mapstructure:",squash"`
// CacheCooldown is the duration to wait before retrying schema fetches
// after the retry limit has been reached. Defaults to 5 minutes.
CacheCooldown time.Duration `mapstructure:"cache_cooldown"`
// CacheRetryLimit is the number of consecutive failed schema fetch
// attempts allowed before enforcing the cooldown period. Defaults to 5.
CacheRetryLimit int `mapstructure:"cache_retry_limit"`
// PreCache is a list of schema URLs that are downloaded
// and cached at the start of the collector runtime
// in order to avoid fetching data that later on could
// block processing of signals. (Optional field)
Prefetch []string `mapstructure:"prefetch"`
// Targets define what schema families should be
// translated to, allowing older and newer formats
// to conform to the target schema identifier.
Targets []string `mapstructure:"targets"`
}
Config defines the user provided values for the Schema Processor
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
alias
Package alias is a subset of the interfaces defined by pdata and family package to allow for higher code reuse without using generics.
|
Package alias is a subset of the interfaces defined by pdata and family package to allow for higher code reuse without using generics. |
|
metadata
Package metadata contains the autogenerated telemetry and build information for the processor/schema component.
|
Package metadata contains the autogenerated telemetry and build information for the processor/schema component. |
|
migrate
Package migrate provides the functionality to take action on specific schema fields that are consumed by the translation package.
|
Package migrate provides the functionality to take action on specific schema fields that are consumed by the translation package. |
|
race
Package race exists so that it can be possible to check if the race detector has been added into the build to allow for tests that provide no unit test value but perform concurrent actions where the race detector can identify issues.
|
Package race exists so that it can be possible to check if the race detector has been added into the build to allow for tests that provide no unit test value but perform concurrent actions where the race detector can identify issues. |
|
transformer
Package transformer contains various Transformers that represent a high level operation - typically a single "change" block from the schema change file.
|
Package transformer contains various Transformers that represent a high level operation - typically a single "change" block from the schema change file. |
Click to show internal directories.
Click to hide internal directories.