Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for awscloudwatchmetrics receiver.
Types ¶
type Config ¶
type Config struct {
Region string `mapstructure:"region"`
Profile string `mapstructure:"profile"`
IMDSEndpoint string `mapstructure:"imds_endpoint"`
PollInterval time.Duration `mapstructure:"poll_interval"`
Metrics *MetricsConfig `mapstructure:"metrics"`
// contains filtered or unexported fields
}
Config is the overall config structure for the awscloudwatchmetricsreceiver
type MetricDimensionsConfig ¶
type MetricDimensionsConfig struct {
Name string `mapstructure:"Name"`
Value string `mapstructure:"Value"`
// contains filtered or unexported fields
}
MetricDimensionConfig is the configuration for the metric dimensions
type MetricsConfig ¶
type MetricsConfig struct {
Names []*NamedConfig `mapstructure:"named"`
// contains filtered or unexported fields
}
MetricsConfig is the configuration for the metrics part of the receiver added this so we could expand to other inputs such as autodiscover
type NamedConfig ¶
type NamedConfig struct {
Namespace string `mapstructure:"namespace"`
MetricName string `mapstructure:"metric_name"`
Period time.Duration `mapstructure:"period"`
AwsAggregation string `mapstructure:"aws_aggregation"`
Dimensions []MetricDimensionsConfig `mapstructure:"dimensions"`
}
NamesConfig is the configuration for the metric namespace and metric names https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html
Click to show internal directories.
Click to hide internal directories.