faroreceiver

package module
v0.151.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: Apache-2.0 Imports: 21 Imported by: 1

README

Faro Receiver

This receiver can receive telemetry data in Faro format that adheres to the Faro OpenAPI schema.

Status
Stability alpha: logs, traces
Distributions contrib
Issues Open issues Closed issues
Code coverage codecov
Code Owners @dehaansa, @rlankfo, @mar4uk

Receiver Configuration

Faro follows the confighttp configuration, some examples are shown below

Example Configuration
receivers:
  faro:
    endpoint: 'localhost:8081'
Advanced Configuration
receivers:
  faro:
    endpoint: 'localhost:8081'
    cors:
      allowed_origins: "*"

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

Types

type Config

type Config struct {
	confighttp.ServerConfig `mapstructure:",squash"`
}

func (*Config) Unmarshal

func (cfg *Config) Unmarshal(conf *confmap.Conf) error

func (*Config) Validate

func (cfg *Config) Validate() error

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/faro component.
Package metadata contains the autogenerated telemetry and build information for the receiver/faro component.

Jump to