filestatsreceiver

package module
v0.158.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: Apache-2.0 Imports: 18 Imported by: 6

README

File Stats Receiver

The File Stats receiver collects metrics from files specified with a glob pattern.

Status
Stability beta: metrics
Distributions contrib
Issues Open issues Closed issues
Code coverage codecov
Code Owners @atoulme | Seeking more code owners!

Configuration

Note: This receiver was renamed from filestats to file_stats to match the snake_case naming convention. The deprecated component type filestats is still accepted as an alias and will log a deprecation warning.

  • include (required): The glob path for files to watch
  • collection_interval (default = 1m): The interval at which metrics are emitted by this receiver.
  • initial_delay (default = 1s): defines how long this receiver waits before starting.
Example
receivers:
  file_stats:
    include: /tmp/files/*
    collection_interval: 10s
    initial_delay: 1s

See documentation.md for a list of the metrics collected.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

NewFactory creates a new filestats receiver factory.

Types

type Config

type Config struct {
	ControllerConfig     scraperhelper.ControllerConfig `mapstructure:",squash"`
	MetricsBuilderConfig metadata.MetricsBuilderConfig  `mapstructure:",squash"`
	Include              string                         `mapstructure:"include"`
	// contains filtered or unexported fields
}

func (Config) Validate

func (c Config) Validate() error

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/file_stats component.
Package metadata contains the autogenerated telemetry and build information for the receiver/file_stats component.

Jump to