iisreceiver

package module
v0.153.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: Apache-2.0 Imports: 7 Imported by: 9

README

Microsoft IIS Receiver

The Microsoft IIS Receiver grabs metrics about an IIS instance using the Windows Performance Counters. Because of this, it is a Windows only receiver.

Status
Stability beta: metrics
Unsupported Platforms linux, darwin, (windows && arm64)
Distributions contrib
Issues Open issues Closed issues
Code coverage codecov
Code Owners @ishleenk17, @Mrod1598, @pjanotti | Seeking more code owners!

Configuration

The following settings are optional:

  • collection_interval (default = 10s): The interval at which metrics should be emitted by this receiver.
  • initial_delay (default = 1s): defines how long this receiver waits before starting.

Example:

    receivers:
      iis:
        collection_interval: 10s
        initial_delay: 1s

The full list of settings exposed for this receiver are documented in config.go.

Metrics

Details about the metrics produced by this receiver can be found in documentation.md

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

NewFactory creates a factory for iis receiver.

Types

type Config

type Config struct {
	scraperhelper.ControllerConfig `mapstructure:",squash"`
	metadata.MetricsBuilderConfig  `mapstructure:",squash"`
}

Config defines configuration for simple prometheus receiver.

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/iis component.
Package metadata contains the autogenerated telemetry and build information for the receiver/iis component.

Jump to