jaegerreceiver

package module
v0.158.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: Apache-2.0 Imports: 34 Imported by: 26

README

Jaeger Receiver

The Jaeger Receiver receives trace data in the Jaeger format.

Status
Stability beta: traces
Distributions core, contrib, k8s
Issues Open issues Closed issues
Code coverage codecov
Code Owners @yurishkuro

Getting Started

By default, the Jaeger receiver will not serve any protocol. A protocol must be named under the protocols object for the jaeger receiver to start. The below protocols are supported, each supports an optional endpoint object configuration parameter.

  • grpc (default endpoint = localhost:14250)
  • thrift_binary (default endpoint = localhost:6832)
  • thrift_compact (default endpoint = localhost:6831)
  • thrift_http (default endpoint = localhost:14268)

See our security best practices doc to understand how to set the endpoint in different environments.

Examples:

receivers:
  jaeger:
    protocols:
      grpc:
  jaeger/withendpoint:
    protocols:
      grpc:
        endpoint: 0.0.0.0:14260

Advanced Configuration

UDP protocols (currently thrift_binary and thrift_compact) allow setting additional server options:

  • queue_size (default 1000) sets max not yet handled requests to server
  • max_packet_size (default 65_000) sets max UDP packet size
  • workers (default 10) sets number of workers consuming the server queue
  • socket_buffer_size (default 0 - no buffer) sets buffer size of connection socket in bytes

Examples:

protocols:
  thrift_binary:
    endpoint: 0.0.0.0:6832
    queue_size: 5_000
    max_packet_size: 131_072
    workers: 50
    socket_buffer_size: 8_388_608

Several helper files are leveraged to provide additional capabilities automatically:

Remote Sampling

Since version v0.61.0, remote sampling is no longer supported by the jaeger receiver. Since version v0.59.0, the jaegerremotesapmpling extension is available that can be used instead.

Documentation

Overview

Package jaegerreceiver receives Jaeger traces.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

NewFactory creates a new Jaeger receiver factory.

Types

type Config

type Config struct {
	Protocols      Protocols             `mapstructure:"protocols"`
	RemoteSampling *RemoteSamplingConfig `mapstructure:"remote_sampling"`
	// contains filtered or unexported fields
}

Config defines configuration for Jaeger receiver.

func (*Config) Validate

func (cfg *Config) Validate() error

Validate checks the receiver configuration is valid

type ProtocolUDP

type ProtocolUDP struct {
	Endpoint        string          `mapstructure:"endpoint"`
	ServerConfigUDP ServerConfigUDP `mapstructure:",squash"`
	// contains filtered or unexported fields
}

ProtocolUDP is the configuration for a UDP protocol.

type Protocols

type Protocols struct {
	GRPC             configoptional.Optional[configgrpc.ServerConfig] `mapstructure:"grpc"`
	ThriftHTTP       configoptional.Optional[confighttp.ServerConfig] `mapstructure:"thrift_http"`
	ThriftBinaryUDP  configoptional.Optional[ProtocolUDP]             `mapstructure:"thrift_binary"`
	ThriftCompactUDP configoptional.Optional[ProtocolUDP]             `mapstructure:"thrift_compact"`
	// contains filtered or unexported fields
}

Protocols is the configuration for the supported protocols.

type RemoteSamplingConfig

type RemoteSamplingConfig struct {
	HostEndpoint               string                  `mapstructure:"host_endpoint"`
	StrategyFile               string                  `mapstructure:"strategy_file"`
	StrategyFileReloadInterval time.Duration           `mapstructure:"strategy_file_reload_interval"`
	ClientConfig               configgrpc.ClientConfig `mapstructure:",squash"`
	// contains filtered or unexported fields
}

RemoteSamplingConfig defines config key for remote sampling fetch endpoint

type ServerConfigUDP

type ServerConfigUDP struct {
	QueueSize        int `mapstructure:"queue_size"`
	MaxPacketSize    int `mapstructure:"max_packet_size"`
	Workers          int `mapstructure:"workers"`
	SocketBufferSize int `mapstructure:"socket_buffer_size"`
	// contains filtered or unexported fields
}

ServerConfigUDP is the server configuration for a UDP protocol.

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/jaeger component.
Package metadata contains the autogenerated telemetry and build information for the receiver/jaeger component.

Jump to