Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var AdditionalTargetSystems = "n/a"
var MetricsGathererHash = "n/a"
Provided as a build time variable if a development or customer specific JMX Metrics Gatherer needs to be supported
var ScraperHash = "n/a"
Provided as a build time variable if a development or customer specific JMX Scraper needs to be supported
Functions ¶
func NewFactory ¶
Types ¶
type Config ¶ added in v0.24.0
type Config struct {
scraperhelper.ControllerConfig `mapstructure:",squash"`
// The path for the JMX Metric Gatherer or JMX Scraper JAR (/opt/opentelemetry-java-contrib-jmx-metrics.jar by default).
// Supported by: jmx-scraper and jmx-metric-gatherer
JARPath string `mapstructure:"jar_path"`
// The Service URL or host:port for the target coerced to one of form: service:jmx:rmi:///jndi/rmi://<host>:<port>/jmxrmi.
// Supported by: jmx-scraper and jmx-metric-gatherer
Endpoint string `mapstructure:"endpoint"`
// Comma-separated list of systems to monitor
// Supported by: jmx-scraper and jmx-metric-gatherer
TargetSystem string `mapstructure:"target_system"`
// The target source of metric definitions to use for the target system.
// Supported values are: auto, instrumentation and legacy.
// Supported by: jmx-scraper
TargetSource string `mapstructure:"target_source"`
// Comma-separated list of paths to custom YAML metrics definition,
// mandatory when TargetSystem is not set.
// Supported by: jmx-scraper
JmxConfigs string `mapstructure:"jmx_configs"`
// The OTLP exporter settings
// Supported by: jmx-scraper and jmx-metric-gatherer
OTLPExporterConfig otlpExporterConfig `mapstructure:"otlp"`
// The JMX username
// Supported by: jmx-scraper and jmx-metric-gatherer
Username string `mapstructure:"username"`
// The JMX password
// Supported by: jmx-scraper and jmx-metric-gatherer
Password configopaque.String `mapstructure:"password"`
// The keystore path for SSL
// Supported by: jmx-scraper and jmx-metric-gatherer
KeystorePath string `mapstructure:"keystore_path"`
// The keystore password for SSL
// Supported by: jmx-scraper and jmx-metric-gatherer
KeystorePassword configopaque.String `mapstructure:"keystore_password"`
// The keystore type for SSL
// Supported by: jmx-scraper and jmx-metric-gatherer
KeystoreType string `mapstructure:"keystore_type"`
// The truststore path for SSL
// Supported by: jmx-scraper and jmx-metric-gatherer
TruststorePath string `mapstructure:"truststore_path"`
// The truststore password for SSL
// Supported by: jmx-scraper and jmx-metric-gatherer
TruststorePassword configopaque.String `mapstructure:"truststore_password"`
// The truststore type for SSL
// Supported by: jmx-scraper and jmx-metric-gatherer
TruststoreType string `mapstructure:"truststore_type"`
// The JMX remote profile. Should be one of:
// `"SASL/PLAIN"`, `"SASL/DIGEST-MD5"`, `"SASL/CRAM-MD5"`, `"TLS SASL/PLAIN"`, `"TLS SASL/DIGEST-MD5"`, or
// `"TLS SASL/CRAM-MD5"`, though no enforcement is applied.
// Supported by: jmx-scraper and jmx-metric-gatherer
RemoteProfile string `mapstructure:"remote_profile"`
// The SASL/DIGEST-MD5 realm
// Supported by: jmx-scraper and jmx-metric-gatherer
Realm string `mapstructure:"realm"`
// Array of additional JARs to be added to the class path when launching the JMX Metric Gatherer JAR
// Supported by: jmx-scraper and jmx-metric-gatherer
AdditionalJars []string `mapstructure:"additional_jars"`
// Map of resource attributes used by the Java SDK Autoconfigure to set resource attributes
// Supported by: jmx-scraper and jmx-metric-gatherer
ResourceAttributes map[string]string `mapstructure:"resource_attributes"`
// Log level used by the JMX metric gatherer. Should be one of:
// `"trace"`, `"debug"`, `"info"`, `"warn"`, `"error"`, `"off"`
// Supported by: jmx-metric-gatherer
LogLevel string `mapstructure:"log_level"`
}
Click to show internal directories.
Click to hide internal directories.