signalfxreceiver

package module
v0.147.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 30 Imported by: 12

README

SignalFx Receiver

Status
Stability deprecated: metrics, logs
Deprecation of logs Date: 2026-02-13
Migration Note: Use the OTLP receiver instead. This component will be removed in a future release.
Deprecation of metrics Date: 2026-02-13
Migration Note: Use the OTLP receiver instead. This component will be removed in a future release.
Distributions contrib
Issues Open issues Closed issues
Code coverage codecov
Code Owners @dmitryax

The SignalFx receiver accepts:

Configuration

The following settings are required:

  • endpoint (default = localhost:9943): Address and port that the SignalFx receiver should bind to. See our security best practices doc to understand how to set the endpoint in different environments.

The following settings are optional:

  • tls_settings (no default): This is an optional object used to specify if TLS should be used for incoming connections. Both key_file and cert_file are required to support incoming TLS connections.
    • cert_file: Specifies the certificate file to use for TLS connection.
    • key_file: Specifies the key file to use for TLS connection.

Example:

receivers:
  signalfx:
  signalfx/advanced:
    tls:
      cert_file: /test.crt
      key_file: /test.key

The full list of settings exposed for this receiver are documented in config.go with detailed sample configurations in testdata/config.yaml.

⚠ When enabling the SignalFx receiver or exporter, configure both the metrics and logs pipelines.

service:
  pipelines:
    metrics:
      receivers: [signalfx]
      processors: [memory_limiter]
      exporters: [signalfx]
    logs:
      receivers: [signalfx]
      processors: [memory_limiter]
      exporters: [signalfx]

Access token passthrough

Access token passthrough is no longer supported, to achieve similar behavior configure your collector to use the headers_setter extension to pass the access token.

Documentation

Overview

Package signalfxreceiver implements a receiver that can be used by the OpenTelemetry collector to receive data in the SignalFx supported formats.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory added in v0.9.0

func NewFactory() receiver.Factory

NewFactory creates a factory for SignalFx receiver.

Types

type Config

type Config struct {
	confighttp.ServerConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct
}

Config defines configuration for the SignalFx receiver.

func (*Config) Validate added in v0.70.0

func (rCfg *Config) Validate() error

Validate verifies that the endpoint is valid and the configured port is not 0

Directories

Path Synopsis
internal

Jump to