Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶ added in v0.9.0
NewFactory creates a factory for "Simple" Prometheus receiver.
Types ¶
type Config ¶
type Config struct {
ClientConfig confighttp.ClientConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
// CollectionInterval is the interval at which metrics should be collected
CollectionInterval time.Duration `mapstructure:"collection_interval"`
// MetricsPath the path to the metrics endpoint.
MetricsPath string `mapstructure:"metrics_path"`
// Params the parameters to the metrics endpoint.
Params url.Values `mapstructure:"params,omitempty"`
// Labels static labels
Labels map[string]string `mapstructure:"labels,omitempty"`
// Whether or not to use pod service account to authenticate.
UseServiceAccount bool `mapstructure:"use_service_account"`
// JobName allows users to customize the job name optionally.
JobName string `mapstructure:"job_name"`
// contains filtered or unexported fields
}
Config defines configuration for simple prometheus receiver.
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
federation/prom-counter
module
|
|
|
internal
|
|
|
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/prometheus_simple component.
|
Package metadata contains the autogenerated telemetry and build information for the receiver/prometheus_simple component. |
Click to show internal directories.
Click to hide internal directories.