Documentation
¶
Overview ¶
Package solacereceiver receives traces from Solace broker using AMQP 1.0 protocol.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for Solace receiver.
Types ¶
type Authentication ¶
type Authentication struct {
PlainText configoptional.Optional[SaslPlainTextConfig] `mapstructure:"sasl_plain"`
XAuth2 configoptional.Optional[SaslXAuth2Config] `mapstructure:"sasl_xauth2"`
External configoptional.Optional[SaslExternalConfig] `mapstructure:"sasl_external"`
// contains filtered or unexported fields
}
Authentication defines authentication strategies.
type Config ¶
type Config struct {
// The list of solace brokers (default localhost:5671)
Broker []string `mapstructure:"broker"`
// The name of the solace queue to consume from, it is required parameter
Queue string `mapstructure:"queue"`
// The maximum number of unacknowledged messages the Solace broker can transmit, to configure AMQP Link
MaxUnacked int32 `mapstructure:"max_unacknowledged"`
TLS configtls.ClientConfig `mapstructure:"tls,omitempty"`
Auth Authentication `mapstructure:"auth"`
Flow FlowControl `mapstructure:"flow_control"`
}
Config defines configuration for Solace receiver.
type FlowControl ¶ added in v0.67.0
type FlowControl struct {
DelayedRetry configoptional.Optional[FlowControlDelayedRetry] `mapstructure:"delayed_retry"`
// contains filtered or unexported fields
}
FlowControl defines the configuration for what to do in backpressure scenarios, e.g. memorylimiter errors
type FlowControlDelayedRetry ¶ added in v0.67.0
type FlowControlDelayedRetry struct {
Delay time.Duration `mapstructure:"delay"`
// contains filtered or unexported fields
}
FlowControlDelayedRetry represents the strategy of waiting for a defined amount of time (in time.Duration) and attempt redelivery
type SaslExternalConfig ¶
type SaslExternalConfig struct{}
SaslExternalConfig defines the configuration for the SASL External used in conjunction with TLS client authentication.
type SaslPlainTextConfig ¶
type SaslPlainTextConfig struct {
Username string `mapstructure:"username"`
Password configopaque.String `mapstructure:"password"`
// contains filtered or unexported fields
}
SaslPlainTextConfig defines SASL PLAIN authentication.
type SaslXAuth2Config ¶
type SaslXAuth2Config struct {
Username string `mapstructure:"username"`
Bearer string `mapstructure:"bearer"`
// contains filtered or unexported fields
}
SaslXAuth2Config defines the configuration for the SASL XAUTH2 authentication.