tcpcheckreceiver

package module
v0.158.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: Apache-2.0 Imports: 20 Imported by: 1

README

TCP Check Receiver

This receiver creates stats by connecting to a TCP server.

Status
Stability alpha: metrics
Distributions contrib
Issues Open issues Closed issues
Code coverage codecov
Code Owners @atoulme, @michael-burt, @chengchuanpeng, @yanfeng1992

Configuration

Note: This receiver was renamed from tcpcheck to tcp_check to match the snake_case naming convention. The deprecated component type tcpcheck is still accepted as an alias and will log a deprecation warning.

The following settings are required:

  • endpoint

The following settings are optional:

  • collection_interval (default = 60s): This receiver collects metrics on an interval. Valid time units are ns, us (or µs), ms, s, m, h.

Example Configuration

Targets are

receivers:
  tcp_check:
    targets:
      - endpoint: example.com:443
        dialer:
          timeout: 15s
      - endpoint: foobar.com:8080
        dialer:
          timeout: 15s
      - endpoint: localhost:10901

The full list of settings exposed for this receiver are documented here with detailed sample configurations here.

Metrics

Details about the metrics produced by this receiver can be found in metadata.yaml

Documentation

Overview

Copyright The OpenTelemetry Authors SPDX-License-Identifier: Apache-2.0

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

NewFactory creates a factory for tcpcheckreceiver receiver.

Types

type Config

type Config struct {
	ControllerConfig     scraperhelper.ControllerConfig `mapstructure:",squash"`
	MetricsBuilderConfig metadata.MetricsBuilderConfig  `mapstructure:",squash"`
	Targets              []*confignet.TCPAddrConfig     `mapstructure:"targets"`
	// contains filtered or unexported fields
}

Config defines the configuration for the various elements of the receiver agent.

func (*Config) Validate

func (cfg *Config) Validate() error

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/tcp_check component.
Package metadata contains the autogenerated telemetry and build information for the receiver/tcp_check component.

Jump to