Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for Generic Webhook Receiver.
Types ¶
type Config ¶
type Config struct {
confighttp.ServerConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct
ReadTimeout string `mapstructure:"read_timeout"` // wait time for reading request headers in ms. Default is 500ms.
WriteTimeout string `mapstructure:"write_timeout"` // wait time for writing request response in ms. Default is 500ms.
Path string `mapstructure:"path"` // path for data collection. Default is /events
HealthPath string `mapstructure:"health_path"` // path for health check api. Default is /health_check
RequiredHeader RequiredHeader `mapstructure:"required_header"` // optional setting to set a required header for all requests to have
SplitLogsAtNewLine bool `mapstructure:"split_logs_at_newline"` // optional setting to split logs into multiple log records
SplitLogsAtJSONBoundary bool `mapstructure:"split_logs_at_json_boundary"` // optional setting to split logs at JSON object boundaries
ConvertHeadersToAttributes bool `mapstructure:"convert_headers_to_attributes"` // optional to convert all headers to attributes
HeaderAttributeRegex string `mapstructure:"header_attribute_regex"` // optional to convert headers matching a regex to log attributes
}
Config defines configuration for the Generic Webhook receiver.
func (*Config) ShouldSplitLogsAtJSONBoundary ¶ added in v0.133.0
type RequiredHeader ¶ added in v0.83.0
Click to show internal directories.
Click to hide internal directories.