Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for the static bearer token Authenticator extension.
Types ¶
type Config ¶
type Config struct {
// Header specifies the auth-header for the token. Defaults to "Authorization"
Header string `mapstructure:"header,omitempty"`
// Scheme specifies the auth-scheme for the token. Defaults to "Bearer"
Scheme string `mapstructure:"scheme,omitempty"`
// BearerToken specifies the bearer token to use for every RPC.
BearerToken configopaque.String `mapstructure:"token,omitempty"`
// Tokens specifies multiple bearer tokens to use for every RPC.
Tokens []configopaque.String `mapstructure:"tokens,omitempty"`
// Filename points to a file that contains the bearer token(s) to use for every RPC.
Filename string `mapstructure:"filename,omitempty"`
// contains filtered or unexported fields
}
Config specifies how the Per-RPC bearer token based authentication data should be obtained.
Click to show internal directories.
Click to hide internal directories.