Documentation
¶
Index ¶
- type DecoderOption
- type DecoderOptions
- type LogsDecoder
- type LogsDecoderExtension
- type LogsDecoderFactory
- type LogsMarshalerExtension
- type LogsUnmarshalerExtension
- type MetricsDecoder
- type MetricsDecoderExtension
- type MetricsDecoderFactory
- type MetricsMarshalerExtension
- type MetricsUnmarshalerExtension
- type ProfilesMarshalerExtension
- type ProfilesUnmarshalerExtension
- type TracesMarshalerExtension
- type TracesUnmarshalerExtension
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DecoderOption ¶ added in v0.146.0
type DecoderOption func(*DecoderOptions)
DecoderOption defines the functional option for DecoderOptions.
func WithFlushBytes ¶ added in v0.146.0
func WithFlushBytes(b int64) DecoderOption
WithFlushBytes sets the number of bytes after stream decoder should flush. Use WithFlushBytes(0) to disable flushing by byte count.
func WithFlushItems ¶ added in v0.146.0
func WithFlushItems(i int64) DecoderOption
WithFlushItems sets the number of items after stream decoder should flush. Use WithFlushItems(0) to disable flushing by item count.
func WithOffset ¶ added in v0.146.0
func WithOffset(offset int64) DecoderOption
WithOffset defines the initial stream offset for the stream. The exact meaning of the offset may vary by decoder (e.g. bytes, lines, records).
type DecoderOptions ¶ added in v0.146.0
DecoderOptions configures the behavior of stream decoding. FlushBytes and FlushItems control how often the decoder should flush decoded data from the stream. Offset defines the initial stream offset for the stream. Use NewDecoderOptions to construct with default options.
func NewDecoderOptions ¶ added in v0.146.0
func NewDecoderOptions(opts ...DecoderOption) DecoderOptions
type LogsDecoder ¶ added in v0.146.0
type LogsDecoder interface {
// DecodeLogs is expected to be called iteratively to read all derived plog.Logs batches from the stream.
// The last batch of logs should be returned with a nil error. io.EOF error should follow on the subsequent call.
DecodeLogs() (plog.Logs, error)
// Offset returns the offset after the most recent batch read from the stream, or the initial offset.
// The exact meaning of the offset may vary by decoder (e.g. bytes, lines, records).
// You may use this value with WithOffset option to resume reading from the same offset when retrying after a failure.
Offset() int64
}
LogsDecoder unmarshals logs from a stream, returning one batch per DecodeLogs call.
type LogsDecoderExtension ¶ added in v0.146.0
type LogsDecoderExtension interface {
extension.Extension
LogsDecoderFactory
}
LogsDecoderExtension is an extension that unmarshals logs from a stream.
type LogsDecoderFactory ¶ added in v0.148.0
type LogsDecoderFactory interface {
NewLogsDecoder(reader io.Reader, options ...DecoderOption) (LogsDecoder, error)
}
LogsDecoderFactory creates LogsDecoder instances for streaming log deserialization.
type LogsMarshalerExtension ¶
LogsMarshalerExtension is an extension that marshals logs.
type LogsUnmarshalerExtension ¶
type LogsUnmarshalerExtension interface {
extension.Extension
plog.Unmarshaler
}
LogsUnmarshalerExtension is an extension that unmarshals logs.
type MetricsDecoder ¶ added in v0.146.0
type MetricsDecoder interface {
// DecodeMetrics is expected to be called iteratively to read all derived pmetric.Metrics batches from the stream.
// The last batch of metrics should be returned with a nil error. io.EOF error should follow on the subsequent call.
DecodeMetrics() (pmetric.Metrics, error)
// Offset returns the offset after the most recent batch read from the stream, or the initial offset.
// The exact meaning of the offset may vary by decoder (e.g. bytes, lines, records).
// You may use this value with WithOffset option to resume reading from the same offset when retrying after a failure.
Offset() int64
}
MetricsDecoder unmarshals metrics from a stream, returning one batch per DecodeMetrics call.
type MetricsDecoderExtension ¶ added in v0.146.0
type MetricsDecoderExtension interface {
extension.Extension
MetricsDecoderFactory
}
MetricsDecoderExtension is an extension that unmarshals metrics from a stream.
type MetricsDecoderFactory ¶ added in v0.148.0
type MetricsDecoderFactory interface {
NewMetricsDecoder(reader io.Reader, options ...DecoderOption) (MetricsDecoder, error)
}
MetricsDecoderFactory creates MetricsDecoder instances for streaming metric deserialization.
type MetricsMarshalerExtension ¶
MetricsMarshalerExtension is an extension that marshals metrics.
type MetricsUnmarshalerExtension ¶
type MetricsUnmarshalerExtension interface {
extension.Extension
pmetric.Unmarshaler
}
MetricsUnmarshalerExtension is an extension that unmarshals metrics.
type ProfilesMarshalerExtension ¶ added in v0.114.0
ProfilesMarshalerExtension is an extension that marshals profiles.
type ProfilesUnmarshalerExtension ¶ added in v0.114.0
type ProfilesUnmarshalerExtension interface {
extension.Extension
pprofile.Unmarshaler
}
ProfilesUnmarshalerExtension is an extension that unmarshals Profiles.
type TracesMarshalerExtension ¶
TracesMarshalerExtension is an extension that marshals traces.
type TracesUnmarshalerExtension ¶
type TracesUnmarshalerExtension interface {
extension.Extension
ptrace.Unmarshaler
}
TracesUnmarshalerExtension is an extension that unmarshals traces.
Directories
¶
| Path | Synopsis |
|---|---|
|
avrologencodingextension
module
|
|
|
awslogsencodingextension
module
|
|
|
azureencodingextension
module
|
|
|
jaegerencodingextension
module
|
|
|
jsonlogencodingextension
module
|
|
|
otlpencodingextension
module
|
|
|
skywalkingencodingextension
module
|
|
|
textencodingextension
module
|
|
|
zipkinencodingextension
module
|