Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for the OIDC Authenticator extension.
Types ¶
type Config ¶
type Config struct {
// The attribute (header name) to look for auth data. Optional, default value: "authorization".
Attribute string `mapstructure:"attribute"`
// Deprecated: use Providers instead.
// IssuerURL is the base URL for the OIDC provider.
// Required.
IssuerURL string `mapstructure:"issuer_url"`
// Deprecated: use Providers instead.
// Audience of the token, used during the verification.
// For example: "https://accounts.google.com" or "https://login.salesforce.com".
// Required unless IgnoreAudience is true.
Audience string `mapstructure:"audience"`
// Deprecated: use Providers instead.
// When true, this skips validating the audience field.
// Optional.
IgnoreAudience bool `mapstructure:"ignore_audience"`
// Deprecated: use Providers instead.
// The local path for the issuer CA's TLS server cert.
// Optional.
IssuerCAPath string `mapstructure:"issuer_ca_path"`
// Deprecated: use Providers instead.
// The claim to use as the username, in case the token's 'sub' isn't the suitable source.
// Optional.
UsernameClaim string `mapstructure:"username_claim"`
// Deprecated: use Providers instead.
// The claim that holds the subject's group membership information.
// Optional.
GroupsClaim string `mapstructure:"groups_claim"`
// Providers allows configuring multiple OIDC providers.
// Use the getProviderConfigs() method to get the full list of providers, including the legacy configuration.
Providers []ProviderCfg `mapstructure:"providers"`
}
Config has the configuration for the OIDC Authenticator extension.
type ProviderCfg ¶ added in v0.131.0
type ProviderCfg struct {
// IssuerURL is the base URL for the OIDC provider.
// Required.
IssuerURL string `mapstructure:"issuer_url"`
// Audience of the token, used during the verification.
// For example: "https://accounts.google.com" or "https://login.salesforce.com".
// Required unless IgnoreAudience is true.
Audience string `mapstructure:"audience"`
// When true, this skips validating the audience field.
// Optional.
IgnoreAudience bool `mapstructure:"ignore_audience"`
// The local path for the issuer CA's TLS server cert.
// Optional.
IssuerCAPath string `mapstructure:"issuer_ca_path"`
// The claim to use as the username, in case the token's 'sub' isn't the suitable source.
// Optional.
UsernameClaim string `mapstructure:"username_claim"`
// The claim that holds the subject's group membership information.
// Optional.
GroupsClaim string `mapstructure:"groups_claim"`
}
func (*ProviderCfg) Validate ¶ added in v0.131.0
func (p *ProviderCfg) Validate() error
Click to show internal directories.
Click to hide internal directories.