Documentation
¶
Index ¶
- func NewFactory() extension.Factory
- type AgentDescription
- type Capabilities
- type Config
- type OpAMPServer
- func (s OpAMPServer) GetAuthExtensionID() component.ID
- func (s OpAMPServer) GetClient(logger *zap.Logger) client.OpAMPClient
- func (s OpAMPServer) GetEndpoint() string
- func (s OpAMPServer) GetHeaders() map[string]configopaque.String
- func (s OpAMPServer) GetPollingInterval() time.Duration
- func (s OpAMPServer) GetTLSConfig(ctx context.Context) (*tls.Config, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
Types ¶
type AgentDescription ¶ added in v0.99.0
type AgentDescription struct {
// NonIdentifyingAttributes are a map of key-value pairs that may be specified to provide
// extra information about the agent to the OpAMP server.
NonIdentifyingAttributes map[string]string `mapstructure:"non_identifying_attributes"`
// IncludeResourceAttributes determines whether the agent should copy its resource attributes
// to the non identifying attributes. (default: false)
IncludeResourceAttributes bool `mapstructure:"include_resource_attributes"`
}
type Capabilities ¶ added in v0.91.0
type Capabilities struct {
// ReportsEffectiveConfig enables the OpAMP ReportsEffectiveConfig Capability. (default: true)
ReportsEffectiveConfig bool `mapstructure:"reports_effective_config"`
// ReportsHealth enables the OpAMP ReportsHealth Capability. (default: true)
ReportsHealth bool `mapstructure:"reports_health"`
// ReportsAvailableComponents enables the OpAMP ReportsAvailableComponents Capability (default: true)
ReportsAvailableComponents bool `mapstructure:"reports_available_components"`
// AcceptsRestartCommand enables the OpAMP AcceptsRestartCommand Capability (default: false)
AcceptsRestartCommand bool `mapstructure:"accepts_restart_command"`
}
type Config ¶
type Config struct {
Server *OpAMPServer `mapstructure:"server"`
// InstanceUID is a UUID formatted as a 36 character string in canonical
// representation. Auto-generated on start if missing.
InstanceUID string `mapstructure:"instance_uid"`
// Capabilities contains options to enable a particular OpAMP capability
Capabilities Capabilities `mapstructure:"capabilities"`
// Agent descriptions contains options to modify the AgentDescription message
AgentDescription AgentDescription `mapstructure:"agent_description"`
// PPID is the process ID of the parent for the collector. If the PPID is specified,
// the extension will continuously poll for the status of the parent process, and emit a fatal error
// when the parent process is no longer running.
// If unspecified, the orphan detection logic does not run.
PPID int32 `mapstructure:"ppid"`
// PPIDPollInterval is the time between polling for whether PPID is running.
PPIDPollInterval time.Duration `mapstructure:"ppid_poll_interval"`
}
Config contains the configuration for the opamp extension. Trying to mirror the OpAMP supervisor config for some consistency.
type OpAMPServer ¶
type OpAMPServer struct {
WS *commonFields `mapstructure:"ws,omitempty"`
HTTP *httpFields `mapstructure:"http,omitempty"`
}
OpAMPServer contains the OpAMP transport configuration.
func (OpAMPServer) GetAuthExtensionID ¶ added in v0.112.0
func (s OpAMPServer) GetAuthExtensionID() component.ID
func (OpAMPServer) GetClient ¶ added in v0.96.0
func (s OpAMPServer) GetClient(logger *zap.Logger) client.OpAMPClient
func (OpAMPServer) GetEndpoint ¶ added in v0.96.0
func (s OpAMPServer) GetEndpoint() string
func (OpAMPServer) GetHeaders ¶ added in v0.96.0
func (s OpAMPServer) GetHeaders() map[string]configopaque.String
func (OpAMPServer) GetPollingInterval ¶ added in v0.109.0
func (s OpAMPServer) GetPollingInterval() time.Duration
func (OpAMPServer) GetTLSConfig ¶ added in v0.125.0
GetTLSConfig returns a TLS config if the endpoint is secure (wss or https)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.